@@ -8,11 +8,11 @@ import contextlib
 import inspect
 from functools import reduce
 import os
+import pathlib
 import sys
 import types
 
 import pytest
-from pkg_resources import parse_version
 
 from .django_compat import is_django_unittest  # noqa
 from .fixtures import django_assert_num_queries  # noqa
@@ -22,6 +22,8 @@ from .fixtures import django_db_use_migrations  # noqa
 from .fixtures import django_db_keepdb  # noqa
 from .fixtures import django_db_createdb  # noqa
 from .fixtures import django_db_modify_db_settings  # noqa
+from .fixtures import django_db_modify_db_settings_parallel_suffix  # noqa
+from .fixtures import django_db_modify_db_settings_tox_suffix  # noqa
 from .fixtures import django_db_modify_db_settings_xdist_suffix  # noqa
 from .fixtures import _live_server_helper  # noqa
 from .fixtures import admin_client  # noqa
@@ -38,20 +40,12 @@ from .fixtures import transactional_db  # noqa
 
 from .lazy_django import django_settings_is_configured, skip_if_no_django
 
-try:
-    import pathlib
-except ImportError:
-    import pathlib2 as pathlib
-
 
 SETTINGS_MODULE_ENV = "DJANGO_SETTINGS_MODULE"
 CONFIGURATION_ENV = "DJANGO_CONFIGURATION"
 INVALID_TEMPLATE_VARS_ENV = "FAIL_INVALID_TEMPLATE_VARS"
 
-PY2 = sys.version_info[0] == 2
-
-# pytest 4.2 handles unittest setup/teardown itself via wrapping fixtures.
-_handle_unittest_methods = parse_version(pytest.__version__) < parse_version("4.2")
+_report_header = []
 
 
 # ############### pytest hooks ################
@@ -59,7 +53,7 @@ _handle_unittest_methods = parse_version(pytest.__version__) < parse_version("4.
 
 def pytest_addoption(parser):
     group = parser.getgroup("django")
-    group._addoption(
+    group.addoption(
         "--reuse-db",
         action="store_true",
         dest="reuse_db",
@@ -67,7 +61,7 @@ def pytest_addoption(parser):
         help="Re-use the testing database if it already exists, "
         "and do not remove it when the test finishes.",
     )
-    group._addoption(
+    group.addoption(
         "--create-db",
         action="store_true",
         dest="create_db",
@@ -75,7 +69,7 @@ def pytest_addoption(parser):
         help="Re-create the database, even if it exists. This "
         "option can be used to override --reuse-db.",
     )
-    group._addoption(
+    group.addoption(
         "--ds",
         action="store",
         type=str,
@@ -83,7 +77,7 @@ def pytest_addoption(parser):
         default=None,
         help="Set DJANGO_SETTINGS_MODULE.",
     )
-    group._addoption(
+    group.addoption(
         "--dc",
         action="store",
         type=str,
@@ -91,7 +85,7 @@ def pytest_addoption(parser):
         default=None,
         help="Set DJANGO_CONFIGURATION.",
     )
-    group._addoption(
+    group.addoption(
         "--nomigrations",
         "--no-migrations",
         action="store_true",
@@ -99,7 +93,7 @@ def pytest_addoption(parser):
         default=False,
         help="Disable Django migrations on test setup",
     )
-    group._addoption(
+    group.addoption(
         "--migrations",
         action="store_false",
         dest="nomigrations",
@@ -109,7 +103,7 @@ def pytest_addoption(parser):
     parser.addini(
         CONFIGURATION_ENV, "django-configurations class to use by pytest-django."
     )
-    group._addoption(
+    group.addoption(
         "--liveserver",
         default=None,
         help="Address and port for the live_server fixture.",
@@ -124,7 +118,7 @@ def pytest_addoption(parser):
         type="bool",
         default=True,
     )
-    group._addoption(
+    group.addoption(
         "--fail-on-template-vars",
         action="store_true",
         dest="itv",
@@ -236,7 +230,7 @@ def _get_boolean_value(x, name, default=None):
     except KeyError:
         raise ValueError(
             "{} is not a valid value for {}. "
-            "It must be one of {}." % (x, name, ", ".join(possible_values.keys()))
+            "It must be one of {}.".format(x, name, ", ".join(possible_values.keys()))
         )
 
 
@@ -285,39 +279,25 @@ def pytest_load_initial_conftests(early_config, parser, args):
     ):
         os.environ[INVALID_TEMPLATE_VARS_ENV] = "true"
 
-    # Configure DJANGO_SETTINGS_MODULE
-    if options.ds:
-        ds_source = "command line option"
-        ds = options.ds
-    elif SETTINGS_MODULE_ENV in os.environ:
-        ds = os.environ[SETTINGS_MODULE_ENV]
-        ds_source = "environment variable"
-    elif early_config.getini(SETTINGS_MODULE_ENV):
-        ds = early_config.getini(SETTINGS_MODULE_ENV)
-        ds_source = "ini file"
-    else:
-        ds = None
-        ds_source = None
+    def _get_option_with_source(option, envname):
+        if option:
+            return option, "option"
+        if envname in os.environ:
+            return os.environ[envname], "env"
+        cfgval = early_config.getini(envname)
+        if cfgval:
+            return cfgval, "ini"
+        return None, None
 
-    if ds:
-        early_config._dsm_report_header = "Django settings: %s (from %s)" % (
-            ds,
-            ds_source,
-        )
-    else:
-        early_config._dsm_report_header = None
-
-    # Configure DJANGO_CONFIGURATION
-    dc = (
-        options.dc
-        or os.environ.get(CONFIGURATION_ENV)
-        or early_config.getini(CONFIGURATION_ENV)
-    )
+    ds, ds_source = _get_option_with_source(options.ds, SETTINGS_MODULE_ENV)
+    dc, dc_source = _get_option_with_source(options.dc, CONFIGURATION_ENV)
 
     if ds:
+        _report_header.append("settings: {} (from {})".format(ds, ds_source))
         os.environ[SETTINGS_MODULE_ENV] = ds
 
         if dc:
+            _report_header.append("configuration: {} (from {})".format(dc, dc_source))
             os.environ[CONFIGURATION_ENV] = dc
 
             # Install the django-configurations importer
@@ -335,12 +315,12 @@ def pytest_load_initial_conftests(early_config, parser, args):
     _setup_django()
 
 
-def pytest_report_header(config):
-    if config._dsm_report_header:
-        return [config._dsm_report_header]
+def pytest_report_header():
+    if _report_header:
+        return ["django: " + ", ".join(_report_header)]
 
 
-@pytest.mark.trylast
+@pytest.hookimpl(trylast=True)
 def pytest_configure():
     # Allow Django settings to be configured in a user pytest_configure call,
     # but make sure we call django.setup()
@@ -364,13 +344,7 @@ def _classmethod_is_defined_at_leaf(cls, method_name):
     try:
         f = method.__func__
     except AttributeError:
-        pytest.fail("%s.%s should be a classmethod" % (cls, method_name))
-    if PY2 and not (
-        inspect.ismethod(method)
-        and inspect.isclass(method.__self__)
-        and issubclass(cls, method.__self__)
-    ):
-        pytest.fail("%s.%s should be a classmethod" % (cls, method_name))
+        pytest.fail("{}.{} should be a classmethod".format(cls, method_name))
     return f is not super_method.__func__
 
 
@@ -419,14 +393,22 @@ def _restore_class_methods(cls):
         cls.tearDownClass = tearDownClass
 
 
-def pytest_runtest_setup(item):
-    if _handle_unittest_methods:
-        if django_settings_is_configured() and is_django_unittest(item):
-            _disable_class_methods(item.cls)
+@pytest.hookimpl(tryfirst=True)
+def pytest_collection_modifyitems(items):
+    # If Django is not configured we don't need to bother
+    if not django_settings_is_configured():
+        return
 
+    from django.test import TestCase, TransactionTestCase
 
-def pytest_collection_modifyitems(session, config, items):
     def get_order_number(test):
+        if hasattr(test, "cls") and test.cls:
+            # Beware, TestCase is a subclass of TransactionTestCase
+            if issubclass(test.cls, TestCase):
+                return 0
+            if issubclass(test.cls, TransactionTestCase):
+                return 1
+
         marker_db = test.get_closest_marker('django_db')
         if marker_db:
             transaction = validate_django_db(marker_db)[0]
@@ -516,38 +498,24 @@ def _django_setup_unittest(request, django_db_blocker):
         yield
         return
 
-    request.getfixturevalue("django_db_setup")
+    # Fix/patch pytest.
+    # Before pytest 5.4: https://github.com/pytest-dev/pytest/issues/5991
+    # After pytest 5.4: https://github.com/pytest-dev/pytest-django/issues/824
+    from _pytest.unittest import TestCaseFunction
+    original_runtest = TestCaseFunction.runtest
 
-    cls = request.node.cls
+    def non_debugging_runtest(self):
+        self._testcase(result=self)
 
-    # implement missing (as of 1.10) debug() method for django's TestCase
-    # see pytest-dev/pytest-django#406
-    def _cleaning_debug(self):
-        testMethod = getattr(self, self._testMethodName)
-        skipped = getattr(self.__class__, "__unittest_skip__", False) or getattr(
-            testMethod, "__unittest_skip__", False
-        )
+    try:
+        TestCaseFunction.runtest = non_debugging_runtest
 
-        if not skipped:
-            self._pre_setup()
-        super(cls, self).debug()
-        if not skipped:
-            self._post_teardown()
-
-    cls.debug = _cleaning_debug
-
-    with django_db_blocker.unblock():
-        if _handle_unittest_methods:
-            _restore_class_methods(cls)
-            cls.setUpClass()
-            _disable_class_methods(cls)
+        request.getfixturevalue("django_db_setup")
 
+        with django_db_blocker.unblock():
             yield
-
-            _restore_class_methods(cls)
-            cls.tearDownClass()
-        else:
-            yield
+    finally:
+        TestCaseFunction.runtest = original_runtest
 
 
 @pytest.fixture(scope="function", autouse=True)
@@ -561,7 +529,7 @@ def _dj_autoclear_mailbox():
 
 
 @pytest.fixture(scope="function")
-def mailoutbox(monkeypatch, django_mail_patch_dns, _dj_autoclear_mailbox):
+def mailoutbox(django_mail_patch_dns, _dj_autoclear_mailbox):
     if not django_settings_is_configured():
         return
 
@@ -578,7 +546,7 @@ def django_mail_patch_dns(monkeypatch, django_mail_dnsname):
 
 
 @pytest.fixture(scope="function")
-def django_mail_dnsname(monkeypatch):
+def django_mail_dnsname():
     return "fake-tests.example.com"
 
 
@@ -589,12 +557,7 @@ def _django_set_urlconf(request):
     if marker:
         skip_if_no_django()
         import django.conf
-
-        try:
-            from django.urls import clear_url_caches, set_urlconf
-        except ImportError:
-            # Removed in Django 2.0
-            from django.core.urlresolvers import clear_url_caches, set_urlconf
+        from django.urls import clear_url_caches, set_urlconf
 
         urls = validate_urls(marker)
         original_urlconf = django.conf.settings.ROOT_URLCONF
@@ -613,7 +576,7 @@ def _django_set_urlconf(request):
 
 
 @pytest.fixture(autouse=True, scope="session")
-def _fail_for_invalid_template_variable(request):
+def _fail_for_invalid_template_variable():
     """Fixture that fails for invalid variables in templates.
 
     This fixture will fail each test that uses django template rendering
@@ -627,7 +590,7 @@ def _fail_for_invalid_template_variable(request):
     ``pytest.mark.ignore_template_errors``
     """
 
-    class InvalidVarException(object):
+    class InvalidVarException:
         """Custom handler for invalid strings in templates."""
 
         def __init__(self):
@@ -675,7 +638,7 @@ def _fail_for_invalid_template_variable(request):
             """Handle TEMPLATE_STRING_IF_INVALID % var."""
             origin = self._get_origin()
             if origin:
-                msg = "Undefined template variable '%s' in '%s'" % (var, origin)
+                msg = "Undefined template variable '{}' in '{}'".format(var, origin)
             else:
                 msg = "Undefined template variable '%s'" % var
             if self.fail:
@@ -730,7 +693,7 @@ def _django_clear_site_cache():
 # ############### Helper Functions ################
 
 
-class _DatabaseBlockerContextManager(object):
+class _DatabaseBlockerContextManager:
     def __init__(self, db_blocker):
         self._db_blocker = db_blocker
 
@@ -741,7 +704,7 @@ class _DatabaseBlockerContextManager(object):
         self._db_blocker.restore()
 
 
-class _DatabaseBlocker(object):
+class _DatabaseBlocker:
     """Manager for django.db.backends.base.base.BaseDatabaseWrapper.
 
     This is the object returned by django_db_blocker.
@@ -768,7 +731,7 @@ class _DatabaseBlocker(object):
     def _blocking_wrapper(*args, **kwargs):
         __tracebackhide__ = True
         __tracebackhide__  # Silence pyflakes
-        pytest.fail(
+        raise RuntimeError(
             "Database access not allowed, "
             'use the "django_db" mark, or the '
             '"db" or "transactional_db" fixtures to enable it.'
